import { OpenAPISpecificationV2, Parameter } from 'openapi-specification-types';
import { OpenAPISpecificationV3 } from 'openapi-specification-types/index-v3';

declare function swagger2ToSwagger3(source: OpenAPISpecificationV3): OpenAPISpecificationV2;

/**
 * Interface for WordPress REST API route
 */
interface WordPressRoute {
    namespace: string;
    endpoints: WordPressEndpoint[];
}
interface WordPressAPISchema {
    routes: Record<string, WordPressRoute>;
}
/**
 * Interface for WordPress REST API endpoint
 */
interface WordPressEndpoint {
    methods: ('get' | 'post' | 'put' | 'delete')[];
    description?: string;
    args?: Record<string, WordPressArgument>;
}
/**
 * Interface for WordPress REST API argument
 */
interface WordPressArgument {
    type?: string | string[];
    description?: string;
    required?: boolean;
    enum?: string[];
    default?: any;
    items?: {
        type?: string;
    };
    maximum?: number;
    minimum?: number;
    format?: string;
    schema?: any;
}

/**
 * Converts WordPress-style endpoints to Swagger style
 * Example: /wp/v2/posts/(?P<id>[\d]+) -> /wp/v2/posts/{id}
 * @param endpoint WordPress endpoint path
 * @returns Swagger-compatible path
 */
declare function convertEndpoint(endpoint: string): string;
/**
 * Extracts path parameters from an endpoint
 * @param endpoint WordPress endpoint path
 * @returns Array of Swagger parameters
 */
declare function getParametersFromEndpoint(endpoint: string): Parameter[];
/**
 * Builds a parameter object from parameter definition
 * @param name Parameter name
 * @param method HTTP method
 * @param endpoint Endpoint path
 * @param detail Parameter details
 * @returns Swagger parameter object
 */
declare function buildParam(name: string, method: string, endpoint: string, detail: WordPressArgument): Parameter;
/**
 * Extracts parameters from argument definitions
 * @param endpoint Endpoint path
 * @param args Argument definitions
 * @param method HTTP method
 * @returns Array of Swagger parameters
 */
declare function getParametersFromArgs(endpoint: string, args: Record<string, WordPressArgument>, method: string): Parameter[];

/**
 * Converts WordPress REST API schema to Swagger v2 format
 * @param source WordPress REST API schema
 * @returns Swagger v2 document
 */
declare function wpapiToSwagger2(source: WordPressAPISchema): OpenAPISpecificationV2;

declare const _default: {
    swagger2ToSwagger3: typeof swagger2ToSwagger3;
    wpapiToSwagger2: typeof wpapiToSwagger2;
};

export { buildParam, convertEndpoint, _default as default, getParametersFromArgs, getParametersFromEndpoint, swagger2ToSwagger3, wpapiToSwagger2 };
