// src/swagger2-to-swagger3/index.ts
function swagger2ToSwagger3(source) {
  const change = source;
  if (source.openapi?.startsWith("3")) {
    const target = source;
    change.swagger = target.openapi;
    change.host = target.servers[0]?.url;
    change.basePath = target.servers[0]?.url;
    change.schemes = target.servers.map((v) => v.url);
    change.info = target.info;
    change.paths = target.paths;
    change.definitions = target.components.schemas;
    change.tags = target.tags;
    change.externalDocs = target.externalDocs;
  }
  return change;
}

// src/wpapi-to-swagger2/utils.ts
function convertEndpoint(endpoint) {
  if (endpoint.includes("(?P<"))
    return endpoint.replace(/\(\?P<([^>]+)>[^)]+\)/g, "{$1}");
  return endpoint;
}
function getParametersFromEndpoint(endpoint) {
  const pathParams = [];
  const regex = /\(\?P<([^>]+)>([^)]+)\)/g;
  let match;
  while ((match = regex.exec(endpoint)) !== null) {
    const name = match[1];
    const pattern = match[2];
    const type = pattern.includes("\\d") ? "integer" : "string";
    const param = {
      name,
      in: "path",
      description: "",
      required: true,
      type
    };
    if (type === "integer")
      param.format = "int64";
    pathParams.push(param);
  }
  return pathParams;
}
function buildParam(name, method, endpoint, detail) {
  const typeValue = detail.type || "string";
  let type = "string";
  if (Array.isArray(typeValue) && typeValue.length > 0)
    type = typeValue[0];
  else if (typeof typeValue === "string")
    type = typeValue;
  if (!type) {
    if (name.includes("_id") || name.toLowerCase() === "id")
      type = "integer";
    else
      type = "string";
  }
  let paramIn = "query";
  if (endpoint.includes(`{${name}}`))
    paramIn = "path";
  else if (method === "post" || method === "put")
    paramIn = "formData";
  let required = !!detail.required;
  if (paramIn === "path")
    required = true;
  const param = {
    type,
    description: detail.description || "",
    in: paramIn,
    name,
    required
  };
  if (detail.enum) {
    param.type = "array";
    param.items = { type: typeof typeValue === "string" ? typeValue : "string", enum: detail.enum };
    if (detail.default !== void 0 && param.items)
      param.items.default = detail.default;
    param.collectionFormat = "multi";
  } else if (detail.items) {
    param.items = { type: detail.items.type || "string" };
  }
  detail.maximum !== void 0 && (param.maximum = detail.maximum);
  detail.minimum !== void 0 && (param.minimum = detail.minimum);
  if (detail.format)
    param.format = detail.format;
  else if (type === "integer")
    param.format = "int64";
  if (detail.schema)
    param.schema = detail.schema;
  return param;
}
function getParametersFromArgs(endpoint, args, method) {
  const parameters = [];
  for (const [param, detail] of Object.entries(args))
    parameters.push(buildParam(param, method, endpoint, detail));
  return parameters;
}

// src/wpapi-to-swagger2/index.ts
function wpapiToSwagger2(source) {
  const swagger = {
    swagger: "2.0",
    basePath: "",
    host: "",
    info: {
      title: "WordPress REST API",
      version: "1.0",
      description: "Using the WordPress REST API you can create a plugin to provide an entirely new admin experience for WordPress, build a brand new interactive front-end experience, or bring your WordPress content into completely separate applications."
    },
    definitions: {},
    consumes: [],
    externalDocs: {},
    paths: {},
    schemes: ["https", "http"],
    securityDefinitions: {
      basic: {
        type: "basic",
        description: "Basic authentication"
      }
    },
    tags: []
  };
  for (const [path, route] of Object.entries(source.routes)) {
    for (const endpoint of route.endpoints) {
      const methods = endpoint.methods;
      const convertedPath = convertEndpoint(path);
      const pathParameters = getParametersFromEndpoint(path);
      for (const method of methods) {
        const parameters = getParametersFromArgs(
          convertedPath,
          endpoint.args || {},
          method
        );
        const allParameters = [...parameters];
        const existingNames = new Set(parameters.map((param) => param.name));
        for (const param of pathParameters) {
          if (!existingNames.has(param.name))
            allParameters.push(param);
        }
        const tags = [route.namespace];
        const responses = {
          200: { description: "OK" },
          400: { description: "Bad Request" },
          404: { description: "Not Found" }
        };
        const consumes = [
          "application/json",
          "application/x-www-form-urlencoded",
          "multipart/form-data"
        ];
        const produces = ["application/json"];
        const security = [{ basic: [] }];
        const operationId = `${method}${convertedPath.replace(/\//g, "_").replace(/\{|\}/g, "")}`;
        swagger.paths[convertedPath] = swagger.paths[convertedPath] ?? {};
        swagger.paths[convertedPath][method] = {
          tags,
          summary: endpoint.description || "",
          description: endpoint.description || "",
          operationId,
          consumes,
          produces,
          parameters: allParameters,
          responses,
          security
        };
      }
    }
  }
  return swagger;
}

// src/index.ts
var index_default = {
  swagger2ToSwagger3,
  wpapiToSwagger2
};
export {
  buildParam,
  convertEndpoint,
  index_default as default,
  getParametersFromArgs,
  getParametersFromEndpoint,
  swagger2ToSwagger3,
  wpapiToSwagger2
};
